.. _Foundation: http://github.com/zurb/foundation
.. _Compass: http://compass-style.org/
.. _Optimus: https://github.com/sveetch/Optimus

This is an `Optimus`_ template project for `Foundation`_.

See the `Optimus`_ documentation for more details.

Requires
========

* `Optimus`_
* `Compass`_
* `Foundation`_

Usage
=====

After you have installed everything, you just have to use it like so : ::

    optimus-cli init --template=optimus_foundation --name=myproject

This will create a new Optimus project filled with Foundation.
